@@ -54,6 +54,18 @@ test_that('param ranges', {
   expect_equal(rule_bands(c(5L, 10L))$range, list(lower = 5L, upper = 10L))
   expect_equal(max_rules(c(5L, 10L))$range, list(lower = 5L, upper = 10L))
   expect_equal(extrapolation(c(1, 10))$range, list(lower = 1, upper = 10))
+  expect_equal(momentum(c(.1, .5))$range, list(lower = .1, upper = .5))
+  expect_equal(stop_iter(c(7L, 15L))$range, list(lower = 7L, upper = 15L))
+  expect_equal(conditional_min_criterion(c(1, 2))$range, list(lower = 1, upper = 2))
+  expect_equal(adjust_deg_free(c(1/2, 3.0))$range, list(lower = 1/2, upper = 3.0))
+  expect_equal(scale_pos_weight(c(1/2, 3.0))$range, list(lower = 1/2, upper = 3.0))
+  expect_equal(prior_slab_dispersion(c(1, 2))$range, list(lower = 1, upper = 2))
+  expect_equal(prior_mixture_threshold(c(.1, .5))$range, list(lower = .1, upper = .5))
+  expect_equal(shrinkage_correlation(c(.1, .5))$range, list(lower = .1, upper = .5))
+  expect_equal(shrinkage_variance(c(.1, .5))$range, list(lower = .1, upper = .5))
+  expect_equal(shrinkage_frequencies(c(.1, .5))$range, list(lower = .1, upper = .5))
+  expect_equal(penalty_L1(c(-5,3))$range, list(lower = -5, upper = 3))
+  expect_equal(penalty_L2(c(-5,3))$range, list(lower = -5, upper = 3))
 })
 
 
@@ -70,5 +82,11 @@ test_that('param values', {
   expect_equal(fuzzy_thresholding(TRUE)$values, TRUE)
   expect_equal(splitting_rule("gini")$values, "gini")
   expect_equal(unbiased_rules(TRUE)$values, TRUE)
+  expect_equal(conditional_test_type()$values, dials:::values_test_type)
+  expect_equal(conditional_test_statistic()$values, dials:::values_test_statistic)
+  expect_equal(select_features(TRUE)$values, TRUE)
+  expect_equal(regularization_method()$values, dials:::values_regularization_method)
+  expect_equal(diagonal_covariance(TRUE)$values, TRUE)
+
 })
 
